@@ -761,7 +761,7 @@ impl LogicalPlanBuilder {
         delimiter: u8,
         has_header: bool,
         ignore_errors: bool,
-        skip_rows: usize,
+        mut skip_rows: usize,
         stop_after_n_rows: Option<usize>,
         cache: bool,
         schema: Option<Arc<Schema>>,
@@ -782,7 +782,7 @@ impl LogicalPlanBuilder {
                 Some(100),
                 has_header,
                 schema_overwrite,
-                skip_rows,
+                &mut skip_rows,
                 comment_char,
                 quote_char,
             )
@@ -909,10 +909,8 @@ impl LogicalPlanBuilder {
     /// Apply a filter
     pub fn filter(self, predicate: Expr) -> Self {
         let predicate = if has_expr(&predicate, |e| matches!(e, Expr::Wildcard)) {
-            let it = self.0.schema().fields().iter().map(|field| {
-                replace_wildcard_with_column(predicate.clone(), Arc::new(field.name().clone()))
-            });
-            combine_predicates_expr(it)
+            let rewritten = rewrite_projections(vec![predicate], self.0.schema());
+            combine_predicates_expr(rewritten.into_iter())
         } else {
             predicate
         };
