@@ -153,6 +153,43 @@ a,b,c
         assert df.columns == ["foo", "b", "c"]
 
 
+def test_column_rename_and_dtype_overwrite():
+    csv = """
+a,b,c
+1,2,3
+1,2,3
+"""
+    f = io.StringIO(csv)
+    df = pl.read_csv(
+        f,
+        new_columns=["A", "B", "C"],
+        dtype={"A": pl.Utf8, "B": pl.Int64, "C": pl.Float32},
+    )
+    assert df.dtypes == [pl.Utf8, pl.Int64, pl.Float32]
+
+    f = io.StringIO(csv)
+    df = pl.read_csv(
+        f,
+        columns=["a", "c"],
+        new_columns=["A", "C"],
+        dtype={"A": pl.Utf8, "C": pl.Float32},
+    )
+    assert df.dtypes == [pl.Utf8, pl.Float32]
+
+    csv = """
+1,2,3
+1,2,3
+"""
+    f = io.StringIO(csv)
+    df = pl.read_csv(
+        f,
+        new_columns=["A", "B", "C"],
+        dtype={"A": pl.Utf8, "C": pl.Float32},
+        has_headers=False,
+    )
+    assert df.dtypes == [pl.Utf8, pl.Int64, pl.Float32]
+
+
 def test_compressed_csv():
     # gzip compression
     csv = """
@@ -286,3 +323,21 @@ Series: 'mydate' [list]
 	[2020-01-02]
 	[2020-01-05, 2020-01-05]
 ]"""
+
+
+def test_csv_empty_quotes_char():
+    # panicked in: https://github.com/pola-rs/polars/issues/1622
+    pl.read_csv(b"a,b,c,d\nA1,B1,C1,1\nA2,B2,C2,2\n", quote_char="")
+
+
+def test_ignore_parse_dates():
+    csv = """a,b,c
+1,i,16200126
+2,j,16250130
+3,k,17220012
+4,l,17290009""".encode()
+
+    headers = ["a", "b", "c"]
+    dtypes = {k: pl.Utf8 for k in headers}  # Forces Utf8 type for every column
+    df = pl.read_csv(csv, columns=headers, dtype=dtypes)
+    assert df.dtypes == [pl.Utf8, pl.Utf8, pl.Utf8]
